
============
Config
============
.. currentmodule:: polars

.. autosummary::
   :toctree: api/

    Config.set_tbl_formatting
    Config.set_tbl_cell_alignment
    Config.set_ascii_tables
    Config.set_fmt_str_lengths
    Config.set_global_string_cache
    Config.set_tbl_cols
    Config.set_tbl_rows
    Config.set_tbl_width_chars
    Config.set_utf8_tables
    Config.set_tbl_hide_column_separator
    Config.set_tbl_hide_dataframe_shape
    Config.set_tbl_change_column_data_type_position_format
    Config.set_tbl_hide_column_data_types
    Config.set_tbl_hide_column_names
    Config.unset_global_string_cache
    toggle_string_cache
    StringCache
